BollingerBandsUpperIndicator<T extends IndicatorResult> class

Bollinger bands upper indicator

Inheritance

Constructors

BollingerBandsUpperIndicator(CachedIndicator<T> bbm, CachedIndicator<T> deviation, {double k = 2})
Initializes.

Properties

bbm CachedIndicator<T>
The middle indicator of the BollingerBand
final
deviation CachedIndicator<T>
Deviation indicator
final
entries List<IndicatorOHLC>
The entries of the input
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
input IndicatorDataInput
IndicatorDataInput to calculate indicator values on.
finalinherited
k double
Default is 2.
final
lastResultIndex int
Index of the last result that is calculated.
getter/setter pairinherited
results List<T>
List of cached result.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

calculate(int index) → T
Calculates the value of this indicator for the given index without caching it.
override
calculateValues() List<T>
Calculates indicator's result for all entries and caches them.
inherited
copyValuesFrom(covariant BollingerBandsUpperIndicator<T> other) → void
Copies the result of other as its own.
override
createResult({required double quote, required int index}) → T
Creates a IndicatorResult entry.
inherited
getValue(int index) → T
Value of the indicator for the given index.
inherited
invalidate(int index) → void
Invalidates a calculated indicator value for index
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
refreshValueFor(int index) → T
Recalculates indicator's value for the give index and caches it.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited