HLCC4Indicator<T extends IndicatorResult> class

A helper indicator to get the (H + L+ 2* C) / 4 value of a list of IndicatorOHLC

Inheritance

Constructors

HLCC4Indicator(IndicatorDataInput input)
Initializes

Properties

entries List<IndicatorOHLC>
The entries of the input
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
input IndicatorDataInput
IndicatorDataInput to calculate indicator values on.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

createResult({required double quote, required int index}) → T
Creates a IndicatorResult entry.
inherited
getValue(int index) → T
Value of the indicator for the given index.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited