PositiveDMIndicator<T extends IndicatorResult> class
Positive Directional Movement indicator.
- Inheritance
-
- Object
- Indicator<
T> - CachedIndicator<
T> - PositiveDMIndicator
Constructors
- PositiveDMIndicator(IndicatorDataInput input)
- Initializes a Positive Directional Movement indicator.
Properties
-
entries
→ List<
IndicatorOHLC> -
The entries of the input
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- input → IndicatorDataInput
-
IndicatorDataInput to calculate indicator values on.
finalinherited
- lastResultIndex ↔ int
-
Index of the last result that is calculated.
getter/setter pairinherited
-
results
→ List<
T> -
List of cached result.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
calculate(
int index) → T -
Calculates the value of this indicator for the given
indexwithout caching it.override -
calculateValues(
) → List< T> -
Calculates indicator's result for all entries and caches them.
inherited
-
copyValuesFrom(
covariant CachedIndicator< T> other) → void -
Copies the result of
otheras its own.inherited -
createResult(
{required double quote, required int index}) → T -
Creates a IndicatorResult entry.
inherited
-
getValue(
int index) → T -
Value of the indicator for the given
index.inherited -
invalidate(
int index) → void -
Invalidates a calculated indicator value for
indexinherited -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
refreshValueFor(
int index) → T -
Recalculates indicator's value for the give
indexand caches it.inherited -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited