PreviousValueIndicator<T extends IndicatorResult> class

An indicator which calculates the previous values of the given indicator.

Inheritance

Constructors

PreviousValueIndicator.fromIndicator(Indicator<T> indicator, {int period = 1})
Initializes A PreviousValueIndicator.

Properties

entries List<IndicatorOHLC>
The entries of the input
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
indicator Indicator<T>
The indicator to calculate the previous value of.
final
input IndicatorDataInput
IndicatorDataInput to calculate indicator values on.
finalinherited
lastResultIndex int
Index of the last result that is calculated.
getter/setter pairinherited
period int
The period to calculate the previous value from.
final
results List<T>
List of cached result.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

calculate(int index) → T
Calculates the value of this indicator for the given index without caching it.
override
calculateValues() List<T>
Calculates indicator's result for all entries and caches them.
inherited
copyValuesFrom(covariant CachedIndicator<T> other) → void
Copies the result of other as its own.
inherited
createResult({required double quote, required int index}) → T
Creates a IndicatorResult entry.
inherited
getValue(int index) → T
Value of the indicator for the given index.
inherited
invalidate(int index) → void
Invalidates a calculated indicator value for index
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
refreshValueFor(int index) → T
Recalculates indicator's value for the give index and caches it.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited