acme_indicators library
Classes
-
AbstractEMAIndicator<
T extends IndicatorResult> - Base class for Exponential Moving Average implementations.
-
ADXHistogramIndicator<
T extends IndicatorResult> - A Histogram ADX Indicator which will be calculated from the given Positive and Negative DI Indicator
-
ADXIndicator<
T extends IndicatorResult> - Average Directional Movement. Part of the Directional Movement System.
-
AroonDownIndicator<
T extends IndicatorResult> - Aroon Down indicator.
-
AroonOscillatorIndicator<
T extends IndicatorResult> - Calculates the value for Aroon Oscillator Indicator.
-
AroonUpIndicator<
T extends IndicatorResult> - Aroon Up Indicator
-
ATRIndicator<
T extends IndicatorResult> - Average true range indicator.
-
AwesomeOscillatorIndicator<
T extends IndicatorResult> - Awesome Oscillator Indicator
-
BearishIndicator<
T extends IndicatorResult> - Bearish Indicator
-
BollingerBandsLowerIndicator<
T extends IndicatorResult> - Bollinger bands lower indicator
-
BollingerBandsUpperIndicator<
T extends IndicatorResult> - Bollinger bands upper indicator
-
BollingerBandWidthIndicator<
T extends IndicatorResult> - Bollinger Band Width indicator.
-
BullishIndicator<
T extends IndicatorResult> - Bullish Indicator
-
CachedIndicator<
T extends IndicatorResult> - Calculates and keeps the result of indicator calculation values in results. And decides when to calculate indicator's value for an index.
-
CloseValueIndicator<
T extends IndicatorResult> - A helper indicator which gets the close values of List of IndicatorOHLC
-
CommodityChannelIndexIndicator<
T extends IndicatorResult> - Commodity Channel Index Indicator.
-
DEMAIndicator<
T extends IndicatorResult> - Double EMA indicator.
-
DonchianMiddleChannelIndicator<
T extends IndicatorResult> - Calculates the value for donchian middle channel.
-
DPOIndicator<
T extends IndicatorResult> - Detrended Price Oscillator Indicator
-
DXIndicator<
T extends IndicatorResult> - Directional movement line Indicator.
-
EMAIndicator<
T extends IndicatorResult> - EMA indicator
-
FastStochasticIndicator<
T extends IndicatorResult> - %K also known as the Fast Stochastic Indicator. A stochastic oscillator is a popular technical indicator for generating overbought and oversold signals.
-
FCBHighIndicator<
T extends IndicatorResult> - FractalChaosBand High Indicator
-
FCBLowIndicator<
T extends IndicatorResult> - FractalChaosBand Low Indicator
-
GainIndicator<
T extends IndicatorResult> - Gain indicator.
-
GatorOscillatorIndicatorBottomBar<
T extends IndicatorResult> - Gator Oscillator Indicator Bottom bar
-
GatorOscillatorIndicatorTopBar<
T extends IndicatorResult> - Gator Oscillator Indicator Top bar
-
HighestValueIndicator<
T extends IndicatorResult> - Highest value in a range
-
HighValueIndicator<
T extends IndicatorResult> - A helper indicator to get the high value of a list of IndicatorOHLC
-
HL2Indicator<
T extends IndicatorResult> -
A helper indicator to get the
(H + L) / 2value of a list of IndicatorOHLC -
HLC3Indicator<
T extends IndicatorResult> -
A helper indicator to get the
(H + L+ C) / 3value of a list of IndicatorOHLC -
HLCC4Indicator<
T extends IndicatorResult> -
A helper indicator to get the
(H + L+ 2* C) / 4value of a list of IndicatorOHLC -
HMAIndicator<
T extends IndicatorResult> - Hull Moving Average indicator
-
IchimokuBaseLineIndicator<
T extends IndicatorResult> -
An
indicatorto calculate average ofHighest HighandLowest Lowin the last given number ofperiods which is set to26by default. -
IchimokuConversionLineIndicator<
T extends IndicatorResult> -
An
indicatorto calculate average ofHighest HighandLowest Lowin the last given number ofperiods which is set to9by default. -
IchimokuLaggingSpanIndicator<
T extends IndicatorResult> -
An
indicatorto calculate theclosevalue the given number of offsets ago. -
IchimokuLineIndicator<
T extends IndicatorResult> -
An abstract class for calculating (
Highest High+Lowest Low) / 2 in the given passedperiods. -
IchimokuSpanAIndicator<
T extends IndicatorResult> -
An
indicatorto calculate average of the given conversionLineIndicator and baseLineIndicator. -
IchimokuSpanBIndicator<
T extends IndicatorResult> -
An
indicatorto calculate average ofHighest HighandLowest Lowin the last given number ofperiods which is set to52by default. -
Indicator<
T extends IndicatorResult> - Base class of all indicators.
- IndicatorDataInput
- Indicators input data.
- IndicatorOHLC
- OHLC interface
- IndicatorResult
- An element of Indicator result
-
LossIndicator<
T extends IndicatorResult> - Loss indicator.
-
LowestValueIndicator<
T extends IndicatorResult> - Lowest value in a range
-
LowValueIndicator<
T extends IndicatorResult> - A helper indicator to get the low value of a list of IndicatorOHLC
-
LSMAIndicator<
T extends IndicatorResult> - Least Square Moving Average indicator
-
MACDHistogramIndicator<
T extends IndicatorResult> - Histogram of Moving Average Convergance Divergence Indicator. Difference of MACD & SignalMACD Indicator.
-
MACDIndicator<
T extends IndicatorResult> - Moving Average Convergence Divergence Indicator.
-
MAEnvLowerIndicator<
T extends IndicatorResult> - Moving Average Envelope lower indicator
-
MAEnvUpperIndicator<
T extends IndicatorResult> - Moving Average Envelope upper indicator
-
MMAIndicator<
T extends IndicatorResult> - Modified moving average indicator.
-
NegativeDIIndicator<
T extends IndicatorResult> - Negative Directional indicator. Part of the Directional Movement System.
-
NegativeDMIndicator<
T extends IndicatorResult> - Negative Directional Movement indicator.
-
OHLC4Indicator<
T extends IndicatorResult> -
A helper indicator to get the
(O+ H + L+ C) / 4value of a list of IndicatorOHLC -
OpenValueIndicator<
T extends IndicatorResult> - A helper indicator to get the open value of a list of IndicatorDataInput
-
ParabolicSarIndicator<
T extends IndicatorResult> - Parabolic Sar Indicator
-
PositiveDIIndicator<
T extends IndicatorResult> - Positive Directional indicator. Part of the Directional Movement System.
-
PositiveDMIndicator<
T extends IndicatorResult> - Positive Directional Movement indicator.
-
PreviousValueIndicator<
T extends IndicatorResult> - An indicator which calculates the previous values of the given indicator.
-
ROCIndicator<
T extends IndicatorResult> - Price Rate Of Change Indicator indicator.
-
RSIIndicator<
T extends IndicatorResult> - Relative strength index indicator.
-
SignalMACDIndicator<
T extends IndicatorResult> - Signal of Moving Average Convergence Divergence Indicator. Normally a 9-day period EMA of MACD.
-
SlowStochasticIndicator<
T extends IndicatorResult> - %D also known as the Slow Stochastic Indicator. It is a 3-period moving average of %K.
-
SMAIndicator<
T extends IndicatorResult> - Simple Moving Average Indicator
-
SMIIndicator<
T extends IndicatorResult> - Stochastic Momentum Index indicator
-
SmoothedFastStochasticIndicator<
T extends IndicatorResult> - A stochastic oscillator is a popular technical indicator for generating overbought and oversold signals.
-
SmoothedSlowStochasticIndicator<
T extends IndicatorResult> - A stochastic oscillator is a popular technical indicator for generating overbought and oversold signals.
-
StandardDeviationIndicator<
T extends IndicatorResult> - Standard deviation indicator.
-
TEMAIndicator<
T extends IndicatorResult> - Triple EMA indicator.
-
TRIMAIndicator<
T extends IndicatorResult> - Triangular Moving Average indicator
-
TRIndicator<
T extends IndicatorResult> - True range indicator.
-
VarianceIndicator<
T extends IndicatorResult> - Variance indicator.
-
VMAIndicator<
T extends IndicatorResult> - Variable Moving Average Indicator
-
WilliamsRIndicator<
T extends IndicatorResult> - WilliamsRIndicator
-
WMAIndicator<
T extends IndicatorResult> - Weighted Moving Average indicator
-
WWSMAIndicator<
T extends IndicatorResult> - Welles Wilder Moving Average Indicator
-
ZigZagIndicator<
T extends IndicatorResult> - The ZigZag Indicator that shows if value changes enough
-
ZLEMAIndicator<
T extends IndicatorResult> - Zero-lag Exponential Moving Average indicator
Enums
- ShiftType
- Supported types of shift.
Functions
-
roundDouble(
double value, int places) → double? -
Returns the rounded double with
placesdecimals